﻿#region License
// Copyright (c) Dmitry Antonenko (http://hystrix.com.ua)
// 
// Licensed under the Apache License, Version 2.0 (the "License"); 
// you may not use this file except in compliance with the License. 
// You may obtain a copy of the License at 
// 
// http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software 
// distributed under the License is distributed on an "AS IS" BASIS, 
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
// See the License for the specific language governing permissions and 
// limitations under the License.
// 
// The latest version of this file can be found at http://fluentfilters.codeplex.com/
#endregion

namespace FluentFilters
{
    using System.Web;

    public class FluentFiltersBuilder
    {
        #region Constants

        private const string REGISTRY_CONTAINER_KEY = "FilterRegistry.Instance";

        #endregion

        #region Fields

        private static readonly object padlock = new object();

        #endregion

        #region Properties

        /// <summary>
        /// Get or set FilterRegistry instance in current application state
        /// </summary>
        private static FilterRegistry Registry
        {
            get 
            {
                return (FilterRegistry)HttpContext.Current.Application[REGISTRY_CONTAINER_KEY];
            }
            set
            {
                HttpContext.Current.Application.Add(REGISTRY_CONTAINER_KEY, value);
            }
        }

        /// <summary>
        /// Get instance of FilterRegistry
        /// </summary>
        public static IFilterRegistry Current
        {
            get
            {
                lock (padlock)
                {
                    if (Registry == null)
                    {
                        Registry = new FilterRegistry();
                    }
                    return Registry;
                }
            }
        }

        #endregion
    }
}
